@@ -1,13 +1,14 @@
 import pickle
 import sys
 import random
+import os
 
 
 class MarkovChain(object):
     def __init__(self, dbFilePath="markovdb"):
         self.dbFilePath = dbFilePath
         try:
-            with open(dbFilePath, 'rb') as dbfile:
+            with open(os.path.join(os.path.dirname(__file__), dbFilePath), 'rb') as dbfile:
                 self.db = pickle.load(dbfile)
         except IOError as e:
             print('Database file not found, using empty database\n')
@@ -60,7 +61,7 @@ class MarkovChain(object):
                     self.db[word][nextword] /= wordsum
         # Now we dump the db to disk
         try:
-            with open(self.dbFilePath, 'wb') as dbfile:
+            with open(os.path.join(os.path.dirname(__file__), self.dbFilePath), 'wb') as dbfile:
                 pickle.dump(self.db, dbfile)
             # It looks like db was written successfully
             return True
